@@ -241,7 +241,7 @@ getFactTable <- function(x, table, sender="%in%") {
 		error(sender, "matching with character values is only supported for single layer SpatRaster")
 	}
 	d <- levels(x)[[1]]
-	m <- na.omit(match(table, d[,2]))
+	m <- stats::na.omit(match(table, d[,2]))
 	if (length(m) == 0) {
 		return(as.logical(x*0))
 	}
